//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#![deny(warnings)]
#![allow(dead_code)]
#![allow(clippy::new_without_default)]

pub mod s5;
pub mod simu;

pub type ApplicationWindow = simu::Window;

fn create_window(
    args: &[&str]
) -> Result<ApplicationWindow, Box<dyn std::error::Error>> {
    println!("args: {:?}", args);
    let mut window = simu::Window::new(s5::Rect { w: 800.0, h: 600.0 });
    //~~~~ populate window ~~~~
    use std::f64::consts::PI;
    let mut rng = s5::Rng::new();
    for i in 0..16 {
        //~~~~ determine initial state ~~~~
        let kinetics = s5::KineticState {
            x: rng.range(0.0, window.size().w),
            y: rng.range(0.0, window.size().h),
            angle: rng.range(0.0, 2.0 * PI),
            x_speed: rng.sign::<f64>() * rng.range(50.0, 100.0),
            y_speed: rng.sign::<f64>() * rng.range(50.0, 100.0),
            angular_speed: rng.sign::<f64>() * rng.range(PI / 6.0, PI / 2.0),
        };
        let color = s5::Color::new(rng.number(), rng.number(), rng.number());
        let side = rng.range(50.0, 100.0);

        let _unused = i; // FIXME: remove

        //~~~~ create entity ~~~~
        window.add_entity(simu::Entity::new(kinetics, color, side));
    }
    Ok(window)
}

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
